#!/usr/bin/env python
"""
This module provides Block.ListStats data access object.
Block parameters based on current conditions at DBS, are listed by this DAO
"""
from WMCore.Database.DBFormatter import DBFormatter
from dbs.utils.dbsExceptionHandler import dbsExceptionHandler

class ListStats(DBFormatter):
    """
    FileType GetID DAO class.
    """
    def __init__(self, logger, dbi, owner):
        """
        Add schema owner and sql.
        """
        DBFormatter.__init__(self, logger, dbi)
        self.logger = logger
        self.owner = "%s." % owner if not owner in ("", "__MYSQL__") else ""
        self.sql = """SELECT count(*) AS FILE_COUNT, 
			SUM(FILE_SIZE) AS BLOCK_SIZE,
			f.BLOCK_ID AS BLOCK_ID
			FROM %sFILES f 
				WHERE f.IS_FILE_VALID=1
				    AND f.BLOCK_ID = :block_id  group by BLOCK_ID""" % (self.owner)
	
    def execute(self, conn, block_id, transaction = False):
        """
        returns id for a given block = /primds/procds/tier#block
        """	
	if not conn:
            dbsExceptionHandler("dbsException-failed-connect2host", "Oracle/Block/ListStats.  Expects db connection from upper layer.", self.logger.exception)
        binds = {"block_id": block_id}
        result = self.dbi.processData(self.sql, binds, conn, transaction)
        plist = self.formatDict(result)
        assert len(plist) == 1, "Block %s does not exist" % block_id 
        return plist[0]

